.. image:: https://travis-ci.org/scivision/transcarread.svg?branch=master
    :target: https://travis-ci.org/scivision/transcarread

=============
transcar-read
=============

Reads the output of the `TRANSCAR <https://github.com/scivision/transcar>`_ 1-D particle penetration aeronomy model.


Install
=======
::

    python setup.py develop
    
Run
===

* transcar2aurora.py: Generate simulated auroral emissions based on Transcar excitation rates.
* transcar2isr.py: Generate simulated Incoherent Scatter Radar plasma paremters based on Transcar sim.
* transcar2excitationradar.py: plots excitation rates output by Transcar sim.
* PlotTranscarInput.py: plots interpolated transcar inputs (MSIS90).

